#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'timerui.ui'
**
** Created by: Qt User Interface Compiler version 5.6.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TIMERUI_H
#define UI_TIMERUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_timerui
{
public:
    QGridLayout *gridLayout;
    QVBoxLayout *vboxLayout;
    QLabel *label_2;
    QGridLayout *gridLayout1;
    QSpacerItem *spacerItem;
    QSlider *kcfg_KidTimer;
    QLabel *label;
    QSpacerItem *spacerItem1;
    QLabel *timeKidLabel;
    QGridLayout *gridLayout2;
    QSpacerItem *spacerItem2;
    QSlider *kcfg_GrownTimer;
    QLabel *label_3;
    QSpacerItem *spacerItem3;
    QLabel *timeGrownLabel;

    void setupUi(QWidget *timerui)
    {
        if (timerui->objectName().isEmpty())
            timerui->setObjectName(QStringLiteral("timerui"));
        timerui->resize(265, 254);
        gridLayout = new QGridLayout(timerui);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        gridLayout->setHorizontalSpacing(6);
        gridLayout->setVerticalSpacing(6);
        gridLayout->setContentsMargins(9, 9, 9, 9);
        vboxLayout = new QVBoxLayout();
        vboxLayout->setSpacing(6);
        vboxLayout->setObjectName(QStringLiteral("vboxLayout"));
        vboxLayout->setContentsMargins(0, 0, 0, 0);
        label_2 = new QLabel(timerui);
        label_2->setObjectName(QStringLiteral("label_2"));

        vboxLayout->addWidget(label_2);

        gridLayout1 = new QGridLayout();
        gridLayout1->setObjectName(QStringLiteral("gridLayout1"));
        gridLayout1->setHorizontalSpacing(4);
        gridLayout1->setVerticalSpacing(4);
        gridLayout1->setContentsMargins(0, 0, 0, 0);
        spacerItem = new QSpacerItem(219, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout1->addItem(spacerItem, 2, 0, 1, 1);

        kcfg_KidTimer = new QSlider(timerui);
        kcfg_KidTimer->setObjectName(QStringLiteral("kcfg_KidTimer"));
        kcfg_KidTimer->setMaximum(10);
        kcfg_KidTimer->setPageStep(1);
        kcfg_KidTimer->setValue(4);
        kcfg_KidTimer->setSliderPosition(4);
        kcfg_KidTimer->setOrientation(Qt::Horizontal);
        kcfg_KidTimer->setTickPosition(QSlider::TicksBelow);
        kcfg_KidTimer->setTickInterval(1);

        gridLayout1->addWidget(kcfg_KidTimer, 1, 0, 1, 2);

        label = new QLabel(timerui);
        label->setObjectName(QStringLiteral("label"));

        gridLayout1->addWidget(label, 0, 0, 1, 2);

        spacerItem1 = new QSpacerItem(20, 20, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout1->addItem(spacerItem1, 3, 1, 1, 1);

        timeKidLabel = new QLabel(timerui);
        timeKidLabel->setObjectName(QStringLiteral("timeKidLabel"));

        gridLayout1->addWidget(timeKidLabel, 2, 1, 1, 1);


        vboxLayout->addLayout(gridLayout1);

        gridLayout2 = new QGridLayout();
        gridLayout2->setObjectName(QStringLiteral("gridLayout2"));
        gridLayout2->setHorizontalSpacing(4);
        gridLayout2->setVerticalSpacing(4);
        gridLayout2->setContentsMargins(0, 0, 0, 0);
        spacerItem2 = new QSpacerItem(219, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout2->addItem(spacerItem2, 2, 0, 1, 1);

        kcfg_GrownTimer = new QSlider(timerui);
        kcfg_GrownTimer->setObjectName(QStringLiteral("kcfg_GrownTimer"));
        kcfg_GrownTimer->setMaximum(10);
        kcfg_GrownTimer->setPageStep(1);
        kcfg_GrownTimer->setValue(2);
        kcfg_GrownTimer->setSliderPosition(2);
        kcfg_GrownTimer->setOrientation(Qt::Horizontal);
        kcfg_GrownTimer->setTickPosition(QSlider::TicksBelow);
        kcfg_GrownTimer->setTickInterval(1);

        gridLayout2->addWidget(kcfg_GrownTimer, 1, 0, 1, 2);

        label_3 = new QLabel(timerui);
        label_3->setObjectName(QStringLiteral("label_3"));

        gridLayout2->addWidget(label_3, 0, 0, 1, 2);

        spacerItem3 = new QSpacerItem(20, 20, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout2->addItem(spacerItem3, 3, 1, 1, 1);

        timeGrownLabel = new QLabel(timerui);
        timeGrownLabel->setObjectName(QStringLiteral("timeGrownLabel"));

        gridLayout2->addWidget(timeGrownLabel, 2, 1, 1, 1);


        vboxLayout->addLayout(gridLayout2);


        gridLayout->addLayout(vboxLayout, 0, 0, 1, 1);


        retranslateUi(timerui);

        QMetaObject::connectSlotsByName(timerui);
    } // setupUi

    void retranslateUi(QWidget *timerui)
    {
        label_2->setText(tr2i18n("Set the time between 2 letters.", 0));
#ifndef UI_QT_NO_TOOLTIP
        kcfg_KidTimer->setToolTip(tr2i18n("Set the timer (in tenths of seconds)", 0));
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_WHATSTHIS
        kcfg_KidTimer->setWhatsThis(tr2i18n("You can set the time between two letters in Kid mode. Default is 4 tenths of seconds but younger children might need longer time.", 0));
#endif // QT_NO_WHATSTHIS
        label->setText(tr2i18n("<html><head><meta name=\"qrichtext\" content=\"1\" /></head><body style=\" white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;\"><p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Kid Mode</p></body></html>", 0));
        timeKidLabel->setText(QString());
#ifndef UI_QT_NO_TOOLTIP
        kcfg_GrownTimer->setToolTip(tr2i18n("Set the timer (in tenths of seconds)", 0));
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_WHATSTHIS
        kcfg_GrownTimer->setWhatsThis(tr2i18n("You can set the time between two letters in Grown-up mode. Default is 2 tenths of seconds.", 0));
#endif // QT_NO_WHATSTHIS
        label_3->setText(tr2i18n("<html><head><meta name=\"qrichtext\" content=\"1\" /></head><body style=\" white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;\"><p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Grown-up Mode</p></body></html>", 0));
        timeGrownLabel->setText(QString());
        Q_UNUSED(timerui);
    } // retranslateUi

};

namespace Ui {
    class timerui: public Ui_timerui {};
} // namespace Ui

QT_END_NAMESPACE

#endif // TIMERUI_H

