/****************************************************************************
** Meta object code from reading C++ file 'klettres.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/klettres-17.04.3/src/klettres.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'klettres.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_KLettres_t {
    QByteArrayData data[13];
    char stringdata0[187];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KLettres_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KLettres_t qt_meta_stringdata_KLettres = {
    {
QT_MOC_LITERAL(0, 0, 8), // "KLettres"
QT_MOC_LITERAL(1, 9, 18), // "slotChangeLanguage"
QT_MOC_LITERAL(2, 28, 0), // ""
QT_MOC_LITERAL(3, 29, 15), // "slotChangeLevel"
QT_MOC_LITERAL(4, 45, 20), // "slotDownloadNewStuff"
QT_MOC_LITERAL(5, 66, 11), // "slotMenubar"
QT_MOC_LITERAL(6, 78, 18), // "slotUpdateSettings"
QT_MOC_LITERAL(7, 97, 15), // "slotModeGrownup"
QT_MOC_LITERAL(8, 113, 11), // "slotModeKid"
QT_MOC_LITERAL(9, 125, 15), // "slotChangeTheme"
QT_MOC_LITERAL(10, 141, 18), // "optionsPreferences"
QT_MOC_LITERAL(11, 160, 12), // "loadSettings"
QT_MOC_LITERAL(12, 173, 13) // "slotPasteChar"

    },
    "KLettres\0slotChangeLanguage\0\0"
    "slotChangeLevel\0slotDownloadNewStuff\0"
    "slotMenubar\0slotUpdateSettings\0"
    "slotModeGrownup\0slotModeKid\0slotChangeTheme\0"
    "optionsPreferences\0loadSettings\0"
    "slotPasteChar"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KLettres[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      11,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   69,    2, 0x0a /* Public */,
       3,    1,   72,    2, 0x0a /* Public */,
       4,    0,   75,    2, 0x09 /* Protected */,
       5,    0,   76,    2, 0x09 /* Protected */,
       6,    0,   77,    2, 0x09 /* Protected */,
       7,    0,   78,    2, 0x09 /* Protected */,
       8,    0,   79,    2, 0x09 /* Protected */,
       9,    1,   80,    2, 0x09 /* Protected */,
      10,    0,   83,    2, 0x09 /* Protected */,
      11,    0,   84,    2, 0x09 /* Protected */,
      12,    0,   85,    2, 0x09 /* Protected */,

 // slots: parameters
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void KLettres::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KLettres *_t = static_cast<KLettres *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->slotChangeLanguage((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 1: _t->slotChangeLevel((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->slotDownloadNewStuff(); break;
        case 3: _t->slotMenubar(); break;
        case 4: _t->slotUpdateSettings(); break;
        case 5: _t->slotModeGrownup(); break;
        case 6: _t->slotModeKid(); break;
        case 7: _t->slotChangeTheme((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 8: _t->optionsPreferences(); break;
        case 9: _t->loadSettings(); break;
        case 10: _t->slotPasteChar(); break;
        default: ;
        }
    }
}

const QMetaObject KLettres::staticMetaObject = {
    { &KXmlGuiWindow::staticMetaObject, qt_meta_stringdata_KLettres.data,
      qt_meta_data_KLettres,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *KLettres::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KLettres::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_KLettres.stringdata0))
        return static_cast<void*>(const_cast< KLettres*>(this));
    return KXmlGuiWindow::qt_metacast(_clname);
}

int KLettres::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KXmlGuiWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 11;
    }
    return _id;
}
QT_END_MOC_NAMESPACE
